@@ -23,6 +23,7 @@ import sys
 import mock
 from nova import exception
 from nova import safe_utils
+from nova.tests.unit import fake_instance
 from nova.virt import driver as base_driver
 from os_win import exceptions as os_win_exc
 
@@ -112,9 +113,6 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
             # original frame will contain the 'foo' variable.
             self.assertEqual('foofoo', trace.tb_frame.f_locals['foo'])
 
-    def test_need_legacy_block_device_info(self):
-        self.assertFalse(self.driver.need_legacy_block_device_info)
-
     @mock.patch.object(driver.eventhandler, 'InstanceEventHandler')
     def test_init_host(self, mock_InstanceEventHandler):
 
@@ -143,6 +141,11 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
         self.driver.list_instances()
         self.driver._vmops.list_instances.assert_called_once_with()
 
+    def test_estimate_instance_overhead(self):
+        self.driver.estimate_instance_overhead(mock.sentinel.instance)
+        self.driver._vmops.estimate_instance_overhead.assert_called_once_with(
+            mock.sentinel.instance)
+
     @mock.patch.object(driver.HyperVDriver, '_recreate_image_meta')
     def test_spawn(self, mock_recreate_img_meta):
         self.driver.spawn(
@@ -304,14 +307,16 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
 
         mock_destroy.assert_called_once_with(
             mock.sentinel.context, mock.sentinel.instance,
-            mock.sentinel.network_info, mock.sentinel.block_device_info)
+            mock.sentinel.network_info, mock.sentinel.block_device_info,
+            destroy_disks=mock.sentinel.destroy_disks)
 
     def test_pre_live_migration(self):
-        self.driver.pre_live_migration(
+        migrate_data = self.driver.pre_live_migration(
             mock.sentinel.context, mock.sentinel.instance,
             mock.sentinel.block_device_info, mock.sentinel.network_info,
             mock.sentinel.disk_info, mock.sentinel.migrate_data)
 
+        self.assertEqual(mock.sentinel.migrate_data, migrate_data)
         pre_live_migration = self.driver._livemigrationops.pre_live_migration
         pre_live_migration.assert_called_once_with(
             mock.sentinel.context, mock.sentinel.instance,
@@ -325,7 +330,8 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
         post_live_migration = self.driver._livemigrationops.post_live_migration
         post_live_migration.assert_called_once_with(
             mock.sentinel.context, mock.sentinel.instance,
-            mock.sentinel.block_device_info)
+            mock.sentinel.block_device_info,
+            mock.sentinel.migrate_data)
 
     def test_post_live_migration_at_source(self):
         self.driver.post_live_migration_at_source(
@@ -358,12 +364,12 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
             mock.sentinel.src_compute_info, mock.sentinel.dst_compute_info,
             mock.sentinel.block_migration, mock.sentinel.disk_over_commit)
 
-    def test_check_can_live_migrate_destination_cleanup(self):
-        self.driver.check_can_live_migrate_destination_cleanup(
+    def test_cleanup_live_migration_destination_check(self):
+        self.driver.cleanup_live_migration_destination_check(
             mock.sentinel.context, mock.sentinel.dest_check_data)
 
         _livemigrops = self.driver._livemigrationops
-        method = _livemigrops.check_can_live_migrate_destination_cleanup
+        method = _livemigrops.cleanup_live_migration_destination_check
         method.assert_called_once_with(
             mock.sentinel.context, mock.sentinel.dest_check_data)
 
@@ -460,10 +466,22 @@ class HyperVDriverTestCase(test_base.HyperVBaseTestCase):
             mock.sentinel.instance)
 
     def test_get_console_output(self):
-        mock_instance = mock.MagicMock()
-        self.driver.get_console_output(mock.sentinel.context, mock_instance)
-        get_console_output = self.driver._serialconsoleops.get_console_output
-        get_console_output.assert_called_once_with(mock_instance.name)
+        mock_instance = fake_instance.fake_instance_obj(self.context)
+        self.driver.get_console_output(self.context, mock_instance)
+
+        mock_get_console_output = (
+            self.driver._serialconsoleops.get_console_output)
+        mock_get_console_output.assert_called_once_with(
+            mock_instance.name)
+
+    def test_get_serial_console(self):
+        mock_instance = fake_instance.fake_instance_obj(self.context)
+        self.driver.get_console_output(self.context, mock_instance)
+
+        mock_get_serial_console = (
+            self.driver._serialconsoleops.get_console_output)
+        mock_get_serial_console.assert_called_once_with(
+            mock_instance.name)
 
     def test_manage_image_cache(self):
         self.driver.manage_image_cache(mock.sentinel.context,
